.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay 

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

Basic functions
===============

.. _abs-function-reference:
.. doxygenfunction:: abs(const simd_batch<X>& )
   :project: xsimd

.. _fabs-function-reference:
.. doxygenfunction:: fabs(const simd_batch<X>& )
   :project: xsimd

.. _fmod-function-reference:
.. doxygenfunction:: fmod
   :project: xsimd

.. _remainder-func-ref:
.. doxygenfunction:: remainder
   :project: xsimd

.. _fma-function-reference:
.. doxygenfunction:: fma(const simd_batch<X>&, const simd_batch<X>&, const simd_batch<X>&)
   :project: xsimd

.. _fms-function-reference:
.. doxygenfunction:: fms(const simd_batch<X>&, const simd_batch<X>&, const simd_batch<X>&)
   :project: xsimd

.. _fnma-function-reference:
.. doxygenfunction:: fnma(const simd_batch<X>&, const simd_batch<X>&, const simd_batch<X>&)
   :project: xsimd

.. _fnms-function-reference:
.. doxygenfunction:: fnms(const simd_batch<X>&, const simd_batch<X>&, const simd_batch<X>&)
   :project: xsimd

.. _min-function-reference:
.. doxygenfunction:: min(const simd_batch<X>&, const simd_batch<X>&)
   :project: xsimd

.. _max-function-reference:
.. doxygenfunction:: max(const simd_batch<X>&, const simd_batch<X>&)
   :project: xsimd

.. _fmin-function-reference:
.. doxygenfunction:: fmin(const simd_batch<X>&, const simd_batch<X>&)
   :project: xsimd

.. _fmax-function-reference:
.. doxygenfunction:: fmax(const simd_batch<X>&, const simd_batch<X>&)
   :project: xsimd

.. _fdim-function-reference:
.. doxygenfunction:: fdim(const batch<T, N>&, const batch<T, N>&)
   :project: xsimd

.. _clip-function-reference:
.. doxygenfunction:: clip(const batch<T, N>&, const batch<T, N>&, const batch<T, N>&)
   :project: xsimd

